import { existsSync } from 'fs';
import { readFile } from 'fs/promises';
import micromatch from 'micromatch';
import { resolve } from 'path';

function createPatternMatcher(patterns) {
  if (!patterns) return () => true;
  const patternArray = Array.isArray(patterns) ? patterns : [patterns];
  const includePatterns = patternArray.filter((p) => !p.startsWith("!"));
  const excludePatterns = patternArray.filter((p) => p.startsWith("!")).map((p) => p.slice(1));
  return (fileName) => {
    return micromatch.isMatch(fileName, includePatterns, {
      dot: true,
      ignore: excludePatterns
    });
  };
}
function isMatch(fileName, pattern, options) {
  return micromatch.isMatch(fileName, pattern, options);
}
async function waitForFile(filePath, timeout = 5e3) {
  const start = Date.now();
  while (Date.now() - start < timeout)
    if (existsSync(filePath)) {
      try {
        await readFile(filePath, "utf-8");
        return;
      } catch {
        await new Promise((resolve2) => setTimeout(resolve2, 100));
      }
    }
  throw new Error(`File not available after ${timeout}ms: ${filePath}`);
}
function normalizePath(path) {
  return path.replace(/\\/g, "/");
}
const np = normalizePath;
function isPathEqual(path1, path2) {
  return resolve(path1) === resolve(path2);
}

export { createPatternMatcher, isMatch, isPathEqual, normalizePath, np, waitForFile };
//# sourceMappingURL=utils.js.map
//# sourceMappingURL=utils.js.map